@@ -95,6 +95,28 @@ impl<N: Num> Line<N> {
     pub fn reverse(self) -> Self {
         Self(self.end(), self.start())
     }
+
+    pub fn is_direction_negative_x(self) -> bool {
+        self.end().x() < self.start().x()
+    }
+
+    pub fn is_direction_positive_x(self) -> bool {
+        self.start().x() < self.end().x()
+    }
+
+    pub fn is_direction_negative_y(self) -> bool {
+        self.end().y() < self.start().y()
+    }
+
+    pub fn is_direction_positive_y(self) -> bool {
+        self.start().y() < self.end().y()
+    }
+}
+
+impl<N: Num + Signed> Line<N> {
+    pub fn direction_sign(&self) -> Point<N> {
+        self.diff_as_point().sign()
+    }
 }
 
 impl<N: Num + ToSignedClamped> Line<N> {
@@ -846,3 +868,36 @@ mod rotate_around_point {
         assert_eq!(rotation, Line(Point(8, 5), Point(3, 10)));
     }
 }
+
+#[cfg(test)]
+mod direction_sign {
+    use super::*;
+
+    #[test]
+    fn it_should_be_positive_when_end_is_larger() {
+        let line = Line(Point(0.0, 0.0), Point(100.0, 100.0));
+
+        assert_eq!(line.direction_sign(), Point(1.0, 1.0));
+    }
+
+    #[test]
+    fn it_should_be_positive_when_end_is_the_same() {
+        let line = Line(Point(0.0, 0.0), Point(0.0, 0.0));
+
+        assert_eq!(line.direction_sign(), Point(1.0, 1.0));
+    }
+
+    #[test]
+    fn it_should_be_negative_when_end_is_smaller() {
+        let line = Line(Point(0.0, 0.0), Point(-100.0, -100.0));
+
+        assert_eq!(line.direction_sign(), Point(-1.0, -1.0));
+    }
+
+    #[test]
+    fn it_should_be_mix_when_end_is_smaller_and_larger() {
+        let line = Line(Point(0.0, 0.0), Point(100.0, -100.0));
+
+        assert_eq!(line.direction_sign(), Point(1.0, -1.0));
+    }
+}
